# SAVNet

[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![Build Status](https://travis-ci.org/friend1ws/SAVNet.svg?branch=devel)](https://travis-ci.org/friend1ws/SAVNet)

## Introduction

SAVNet is a software for extracting splicing associated variants (SAVs) from somatic mutation, splicing junction and intron retention data. This software has been used for large-scale exome-transcriptome sequence analysis (see our [preprint](https://www.biorxiv.org/content/early/2017/09/28/162560)).

## Documentation

The documentation for SAVNet is available [here](http://savnet.readthedocs.io/en/latest/index.html).
